Returns the names of the endogenous statistics that
endogenous_features() evaluates with the compiled C++ engine.
Statistics outside this set are computed by the (slower) pure-R fallback.
Returns the names of the endogenous statistics that
endogenous_features() evaluates with the compiled C++ engine.
Statistics outside this set are computed by the (slower) pure-R fallback.